@@ -1,5 +1,9 @@
-overview <-
-function (my.inds, cols = 1, n.inds = c(1:length(my.inds)), xlimi=c(min(ladder),max(ladder)), ladder, channel.ladder=dim(my.inds[[1]])[2], ploidy=2, ci.upp=1.96, ci.low=1.96, dev=50, method="iter", init.thresh=200, ladd.init.thresh=200, warn=TRUE, env = parent.frame()) 
+overview <-function (my.inds, cols = 1, n.inds = c(1:length(my.inds)), 
+                     xlimi=c(min(ladder),max(ladder)), ladder, 
+                     channel.ladder=dim(my.inds[[1]])[2], ploidy=2, 
+                     ci.upp=1.96, ci.low=1.96, dev=50, method="iter", 
+                     init.thresh=200, ladd.init.thresh=200, warn=TRUE, 
+                     my.palette=NULL, env = parent.frame()) 
 {
   if(dim(my.inds[[1]])[2] < channel.ladder){
     print(paste("ERROR MY FRIEND!! you have indicated an argument channel.ladder=5, but your data contains less channels/colors"))
@@ -29,7 +33,12 @@ function (my.inds, cols = 1, n.inds = c(1:length(my.inds)), xlimi=c(min(ladder),
   #  require("zoom")
   #}
   ncfp <- c("COL1", "COL2", "COL3", "COL4", "COL5")
-  cfp <- c("cornflowerblue", "chartreuse4", "gold2", "red", "orange", "purple")
+  if(!is.null(my.palette)){
+    cfp <- rep(my.palette,100)
+  }else{
+    cfp <- c("cornflowerblue", "chartreuse4", "gold2", "red", "orange", "purple")
+  }
+  
   col.list <- list(NA)
   att1 <- numeric()
   #####################################################################################################
